<template>
  <view class="page pt-2">
    <z-paging ref="paging" refresher-only class="list">
      <template #top>
        <CardTitle title="报工信息" :hideAction="true" :full="false" @action="addReport" />
      </template>
      <wd-card v-for="(item, index) in 6" type="rectangle" custom-class="round">
        <template #title>
          <view class="flex justify-between">
            <view>
              <wd-icon name="user" color="#0D867F"></wd-icon>
              <text class="text-[#0D867F] ml-2 font-medium">生产人</text>
              <text class="text-[#333333] ml-2">方兆玉</text>
            </view>
            <view class="text-[#A8A8A8]" @click="toEdit">编辑</view>
          </view>
        </template>
        <ProductionCard :data="cardAttr" />
        <template #footer>
          <wd-button size="small" plain @click="toCheck">自检</wd-button>
        </template>
      </wd-card>
      <wd-loadmore custom-class="loadmore" state="loading" />
    </z-paging>

    <wd-popup v-model="dialog.visible" position="bottom" custom-class="yl-popup">
      <view class="action px-3">
        <wd-button type="text" @click="cancel">取消</wd-button>
        <wd-button type="text" @click="submit">确定</wd-button>
      </view>
      <TwistForm />
    </wd-popup>
    <wd-toast />
  </view>
</template>
<script setup lang="ts">
import CardTitle from "@/components/card-title/index.vue";
import TwistForm from "./form.vue";
import { useToast } from "wot-design-uni";
import ProductionCard from "../../components/ProductionCard.vue";

const toast = useToast();
const dialog = reactive({
  visible: false,
});

const cardAttr = ref<any[]>([
  {
    label: "合同号",
    value: "ht2921246",
  },
  {
    label: "状态",
    value: "-----",
  },
  {
    label: "客户名称",
    value: "夏志豪",
  },
  {
    label: "机台",
    value: "-----",
  },
  {
    label: "规格型号",
    value: "2921246",
  },
  {
    label: "已生产数量",
    value: "0",
  },
  {
    label: "盘长(m)",
    value: "292",
  },
  {
    label: "计划数量",
    value: "100",
  },
  {
    label: "质量追溯号",
    value: "JX-1838",
  },
]);

const toEdit = () => {
  uni.navigateTo({
    url: "/pages/production/twist/report/edit",
  });
};

const addReport = () => {
  dialog.visible = true;
};

const submit = () => {
  toast.show("提交");
  dialog.visible = false;
};

const cancel = () => {
  toast.show("取消");
  dialog.visible = false;
};

const toCheck = () => {
  uni.navigateTo({
    url: "/pages/production/twist/selfInspect/index",
  });
};
</script>

<style lang="scss" scoped>
.page {
  background: #f3f9f8;

  .list {
    margin: 12px;

    :deep() {
      .round {
        border-radius: 4px;
      }
    }
  }
}

.action {
  display: flex;
  justify-content: space-between;
}
</style>
